==> v21.10.zip: bookstack/resources/lang/et/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Tühista',
    'confirm' => 'Kinnita',
    'back' => 'Tagasi',
    'save' => 'Salvesta',
    'continue' => 'Jätka',
    'select' => 'Vali',
    'toggle_all' => 'Vaheta kõik',
    'more' => 'Rohkem',

    // Form Labels
    'name' => 'Pealkiri',
    'description' => 'Kirjeldus',
    'role' => 'Roll',
    'cover_image' => 'Kaanepilt',
    'cover_image_description' => 'See pilt peaks olema umbes 440x250 pikslit.',
    
    // Actions
    'actions' => 'Tegevused',
    'view' => 'Vaata',
    'view_all' => 'Vaata kõiki',
    'create' => 'Lisa',
    'update' => 'Uuenda',
    'edit' => 'Muuda',
    'sort' => 'Sorteeri',
    'move' => 'Liiguta',
    'copy' => 'Kopeeri',
    'reply' => 'Vasta',
    'delete' => 'Kustuta',
    'delete_confirm' => 'Kinnita kustutamine',
    'search' => 'Otsi',
    'search_clear' => 'Tühjenda otsing',
    'reset' => 'Taasta',
    'remove' => 'Eemalda',
    'add' => 'Lisa',
    'configure' => 'Seadista',
    'fullscreen' => 'Täisekraan',
    'favourite' => 'Lemmik',
    'unfavourite' => 'Eemalda lemmik',
    'next' => 'Järgmine',
    'previous' => 'Eelmine',

    // Sort Options
    'sort_options' => 'Sorteerimise valikud',
    'sort_direction_toggle' => 'Sorteerimise suund',
    'sort_ascending' => 'Sorteeri kasvavalt',
    'sort_descending' => 'Sorteeri kahanevalt',
    'sort_name' => 'Pealkiri',
    'sort_default' => 'Vaikimisi',
    'sort_created_at' => 'Loomise aeg',
    'sort_updated_at' => 'Muutmise aeg',

    // Misc
    'deleted_user' => 'Kustutatud kasutaja',
    'no_activity' => 'Pole tegevusi, mida näidata',
    'no_items' => 'Ühtegi elementi pole',
    'back_to_top' => 'Tagasi üles',
    'skip_to_main_content' => 'Otse põhisisu juurde',
    'toggle_details' => 'Näita detaile',
    'toggle_thumbnails' => 'Näita eelvaateid',
    'details' => 'Detailid',
    'grid_view' => 'Tabelivaade',
    'list_view' => 'Loendivaade',
    'default' => 'Vaikimisi',
    'breadcrumb' => 'Jäljerida',

    // Header
    'header_menu_expand' => 'Laienda päisemenüü',
    'profile_menu' => 'Profiilimenüü',
    'view_profile' => 'Vaata profiili',
    'edit_profile' => 'Muuda profiili',
    'dark_mode' => 'Tume režiim',
    'light_mode' => 'Hele režiim',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_info_label' => 'Tab: Show Secondary Information',
    'tab_content' => 'Sisu',
    'tab_content_label' => 'Tab: Show Primary Content',

    // Email Content
    'email_action_help' => 'Kui sul on probleeme ":actionText" nupu vajutamisega, kopeeri allolev URL oma veebilehitsejasse:',
    'email_rights' => 'Kõik õigused kaitstud',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privaatsus',
    'terms_of_service' => 'Kasutustingimused',
];

==> v22.11.zip: bookstack/resources/lang/et/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Tühista',
    'confirm' => 'Kinnita',
    'back' => 'Tagasi',
    'save' => 'Salvesta',
    'continue' => 'Jätka',
    'select' => 'Vali',
    'toggle_all' => 'Vaheta kõik',
    'more' => 'Rohkem',

    // Form Labels
    'name' => 'Pealkiri',
    'description' => 'Kirjeldus',
    'role' => 'Roll',
    'cover_image' => 'Kaanepilt',
    'cover_image_description' => 'See pilt peaks olema umbes 440x250 pikslit.',

    // Actions
    'actions' => 'Tegevused',
    'view' => 'Vaata',
    'view_all' => 'Vaata kõiki',
    'new' => 'Uus',
    'create' => 'Lisa',
    'update' => 'Uuenda',
    'edit' => 'Muuda',
    'sort' => 'Sorteeri',
    'move' => 'Liiguta',
    'copy' => 'Kopeeri',
    'reply' => 'Vasta',
    'delete' => 'Kustuta',
    'delete_confirm' => 'Kinnita kustutamine',
    'search' => 'Otsi',
    'search_clear' => 'Tühjenda otsing',
    'reset' => 'Taasta',
    'remove' => 'Eemalda',
    'add' => 'Lisa',
    'configure' => 'Seadista',
    'fullscreen' => 'Täisekraan',
    'favourite' => 'Lemmik',
    'unfavourite' => 'Eemalda lemmik',
    'next' => 'Järgmine',
    'previous' => 'Eelmine',
    'filter_active' => 'Aktiivne filter:',
    'filter_clear' => 'Tühjenda filter',
    'download' => 'Laadi alla',
    'open_in_tab' => 'Ava vahelehel',

    // Sort Options
    'sort_options' => 'Sorteerimise valikud',
    'sort_direction_toggle' => 'Sorteerimise suund',
    'sort_ascending' => 'Sorteeri kasvavalt',
    'sort_descending' => 'Sorteeri kahanevalt',
    'sort_name' => 'Pealkiri',
    'sort_default' => 'Vaikimisi',
    'sort_created_at' => 'Loomise aeg',
    'sort_updated_at' => 'Muutmise aeg',

    // Misc
    'deleted_user' => 'Kustutatud kasutaja',
    'no_activity' => 'Pole tegevusi, mida näidata',
    'no_items' => 'Ühtegi elementi pole',
    'back_to_top' => 'Tagasi üles',
    'skip_to_main_content' => 'Otse põhisisu juurde',
    'toggle_details' => 'Näita detaile',
    'toggle_thumbnails' => 'Näita eelvaateid',
    'details' => 'Detailid',
    'grid_view' => 'Tabelivaade',
    'list_view' => 'Loendivaade',
    'default' => 'Vaikimisi',
    'breadcrumb' => 'Jäljerida',
    'status' => 'Staatus',
    'status_active' => 'Aktiivne',
    'status_inactive' => 'Mitteaktiivne',
    'never' => 'Mitte kunagi',
    'none' => 'Puudub',

    // Header
    'homepage' => 'Avaleht',
    'header_menu_expand' => 'Laienda päisemenüü',
    'profile_menu' => 'Profiilimenüü',
    'view_profile' => 'Vaata profiili',
    'edit_profile' => 'Muuda profiili',
    'dark_mode' => 'Tume režiim',
    'light_mode' => 'Hele režiim',
    'global_search' => 'Globaalne otsing',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_info_label' => 'Sakk: Näita sekundaarset infot',
    'tab_content' => 'Sisu',
    'tab_content_label' => 'Sakk: Näita primaarset sisu',

    // Email Content
    'email_action_help' => 'Kui sul on probleeme ":actionText" nupu vajutamisega, kopeeri allolev URL oma veebilehitsejasse:',
    'email_rights' => 'Kõik õigused kaitstud',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Privaatsus',
    'terms_of_service' => 'Kasutustingimused',
];
